@@ -1,6 +1,6 @@
 #' Bind all list members by row
 #'
-#' @param x The list
+#' @param .data The list
 #' @name list.cbind
 #' @export
 #' @examples
@@ -8,6 +8,6 @@
 #' x <- list(data.frame(i=1:5,x=rnorm(5)),data.frame(y=rnorm(5),z=rnorm(5)))
 #' list.cbind(x)
 #' }
-list.cbind <- function(x) {
-  do.call(cbind,x)
+list.cbind <- function(.data) {
+  list.do(.data,cbind)
 }
