@@ -1,10 +1,9 @@
 #' Iterate a list by evaluating an expression on
 #' each list member.
 #'
-#' @param x The list to iterate
+#' @param .data \code{list}
 #' @param expr An expression that is evaluated for each item
 #' @name list.iter
-#' @return NULL
 #' @export
 #' @examples
 #' \dontrun{
@@ -14,21 +13,8 @@
 #' list.iter(x,cat(paste(type,"\n")))
 #' list.iter(x,cat(str(.)))
 #' }
-
-list.iter <- function(x,expr) {
+list.iter <- function(.data,expr) {
   expr <- substitute(expr)
-  l <- lambda(expr)
-  enclos <- new.env(FALSE,parent.frame(),1)
-  items <- lapply(x,function(i) {
-    assign(l$symbol,i,envir = enclos)
-    if(is.list(i) || is.environment(i)) {
-      env <- i
-    } else if(is.vector(i)) {
-      env <- as.list(i)
-    } else {
-      env <- enclos
-    }
-    eval(l$expr,env,enclos)
-  })
-  invisible(NULL)
+  list.map.internal(.data,expr)
+  invisible()
 }
