@@ -1,6 +1,6 @@
 #' Remove members from a list by index or name
 #'
-#' @param x The list
+#' @param .data \code{list}
 #' @param range A numeric vector of indices or
 #' a character vector of names to remove from \code{x}
 #' @name list.remove
@@ -13,15 +13,15 @@
 #' list.remove(x,"p1")
 #' list.remove(x,c(1,2))
 #' }
-list.remove <- function(x,range=integer()) {
+list.remove <- function(.data,range=integer()) {
   if(is.logical(range)) {
-    x[!range]
+    .data[!range]
   } else if(is.numeric(range)) {
-    x[-range]
+    .data[-range]
   } else if(is.character(range)) {
-    names <- names(x)
-    m <- vapply(range,`==`,logical(length(x)),names)
-    selector <- apply(m,1,any)
-    x[!selector]
+    names <- names(.data)
+    m <- vapply(range,`==`,logical(length(.data)),names)
+    selector <- apply(m,1L,any)
+    .data[!selector]
   }
 }
