@@ -1,6 +1,6 @@
 #' Skip a number of members in a list
 #'
-#' @param x The list from which some members are taken
+#' @param .data \code{list}
 #' @param n The number of members to skip
 #' @name list.skip
 #' @export
@@ -10,6 +10,6 @@
 #' list.skip(x,1)
 #' list.skip(x,2)
 #' }
-list.skip <- function(x,n) {
-  x[-(1:n)]
+list.skip <- function(.data,n) {
+  .data[-(1L:n)]
 }
